==> mypy-boto3-evidently-1.21.23.tar.gz: mypy-boto3-evidently-1.21.23/mypy_boto3_evidently/literals.py <==
"""
Type annotations for evidently service literal definitions.

[Open documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_evidently/literals.html)

Usage::

    ```python
    from mypy_boto3_evidently.literals import ChangeDirectionEnumType

    data: ChangeDirectionEnumType = "DECREASE"
    ```
"""
import sys

if sys.version_info >= (3, 9):
    from typing import Literal
else:
    from typing_extensions import Literal


__all__ = (
    "ChangeDirectionEnumType",
    "EventTypeType",
    "ExperimentBaseStatType",
    "ExperimentReportNameType",
    "ExperimentResultRequestTypeType",
    "ExperimentResultResponseTypeType",
    "ExperimentStatusType",
    "ExperimentStopDesiredStateType",
    "ExperimentTypeType",
    "FeatureEvaluationStrategyType",
    "FeatureStatusType",
    "LaunchStatusType",
    "LaunchStopDesiredStateType",
    "LaunchTypeType",
    "ListExperimentsPaginatorName",
    "ListFeaturesPaginatorName",
    "ListLaunchesPaginatorName",
    "ListProjectsPaginatorName",
    "ProjectStatusType",
    "VariationValueTypeType",
    "CloudWatchEvidentlyServiceName",
    "ServiceName",
    "ResourceServiceName",
    "PaginatorName",
)


ChangeDirectionEnumType = Literal["DECREASE", "INCREASE"]
EventTypeType = Literal["aws.evidently.custom", "aws.evidently.evaluation"]
ExperimentBaseStatType = Literal["Mean"]
ExperimentReportNameType = Literal["BayesianInference"]
ExperimentResultRequestTypeType = Literal[
    "BaseStat", "ConfidenceInterval", "PValue", "TreatmentEffect"
]
ExperimentResultResponseTypeType = Literal[
    "ConfidenceIntervalLowerBound",
    "ConfidenceIntervalUpperBound",
    "Mean",
    "PValue",
    "TreatmentEffect",
]
ExperimentStatusType = Literal["CANCELLED", "COMPLETED", "CREATED", "RUNNING", "UPDATING"]
ExperimentStopDesiredStateType = Literal["CANCELLED", "COMPLETED"]
ExperimentTypeType = Literal["aws.evidently.onlineab"]
FeatureEvaluationStrategyType = Literal["ALL_RULES", "DEFAULT_VARIATION"]
FeatureStatusType = Literal["AVAILABLE", "UPDATING"]
LaunchStatusType = Literal["CANCELLED", "COMPLETED", "CREATED", "RUNNING", "UPDATING"]
LaunchStopDesiredStateType = Literal["CANCELLED", "COMPLETED"]
LaunchTypeType = Literal["aws.evidently.splits"]
ListExperimentsPaginatorName = Literal["list_experiments"]
ListFeaturesPaginatorName = Literal["list_features"]
ListLaunchesPaginatorName = Literal["list_launches"]
ListProjectsPaginatorName = Literal["list_projects"]
ProjectStatusType = Literal["AVAILABLE", "UPDATING"]
VariationValueTypeType = Literal["BOOLEAN", "DOUBLE", "LONG", "STRING"]
CloudWatchEvidentlyServiceName = Literal["evidently"]
ServiceName = Literal[
    "accessanalyzer",
    "account",
    "acm",
    "acm-pca",
    "alexaforbusiness",
    "amp",
    "amplify",
    "amplifybackend",
    "amplifyuibuilder",
    "apigateway",
    "apigatewaymanagementapi",
    "apigatewayv2",
    "appconfig",
    "appconfigdata",
    "appflow",
    "appintegrations",
    "application-autoscaling",
    "application-insights",
    "applicationcostprofiler",
    "appmesh",
    "apprunner",
    "appstream",
    "appsync",
    "athena",
    "auditmanager",
    "autoscaling",
    "autoscaling-plans",
    "backup",
    "backup-gateway",
    "batch",
    "billingconductor",
    "braket",
    "budgets",
    "ce",
    "chime",
    "chime-sdk-identity",
    "chime-sdk-meetings",
    "chime-sdk-messaging",
    "cloud9",
    "cloudcontrol",
    "clouddirectory",
    "cloudformation",
    "cloudfront",
    "cloudhsm",
    "cloudhsmv2",
    "cloudsearch",
    "cloudsearchdomain",
    "cloudtrail",
    "cloudwatch",
    "codeartifact",
    "codebuild",
    "codecommit",
    "codedeploy",
    "codeguru-reviewer",
    "codeguruprofiler",
    "codepipeline",
    "codestar",
    "codestar-connections",
    "codestar-notifications",
    "cognito-identity",
    "cognito-idp",
    "cognito-sync",
    "comprehend",
    "comprehendmedical",
    "compute-optimizer",
    "config",
    "connect",
    "connect-contact-lens",
    "connectparticipant",
    "cur",
    "customer-profiles",
    "databrew",
    "dataexchange",
    "datapipeline",
    "datasync",
    "dax",
    "detective",
    "devicefarm",
    "devops-guru",
    "directconnect",
    "discovery",
    "dlm",
    "dms",
    "docdb",
    "drs",
    "ds",
    "dynamodb",
    "dynamodbstreams",
    "ebs",
    "ec2",
    "ec2-instance-connect",
    "ecr",
    "ecr-public",
    "ecs",
    "efs",
    "eks",
    "elastic-inference",
    "elasticache",
    "elasticbeanstalk",
    "elastictranscoder",
    "elb",
    "elbv2",
    "emr",
    "emr-containers",
    "es",
    "events",
    "evidently",
    "finspace",
    "finspace-data",
    "firehose",
    "fis",
    "fms",
    "forecast",
    "forecastquery",
    "frauddetector",
    "fsx",
    "gamelift",
    "glacier",
    "globalaccelerator",
    "glue",
    "grafana",
    "greengrass",
    "greengrassv2",
    "groundstation",
    "guardduty",
    "health",
    "healthlake",
    "honeycode",
    "iam",
    "identitystore",
    "imagebuilder",
    "importexport",
    "inspector",
    "inspector2",
    "iot",
    "iot-data",
    "iot-jobs-data",
    "iot1click-devices",
    "iot1click-projects",
    "iotanalytics",
    "iotdeviceadvisor",
    "iotevents",
    "iotevents-data",
    "iotfleethub",
    "iotsecuretunneling",
    "iotsitewise",
    "iotthingsgraph",
    "iottwinmaker",
    "iotwireless",
    "ivs",
    "kafka",
    "kafkaconnect",
    "kendra",
    "keyspaces",
    "kinesis",
    "kinesis-video-archived-media",
    "kinesis-video-media",
    "kinesis-video-signaling",
    "kinesisanalytics",
    "kinesisanalyticsv2",
    "kinesisvideo",
    "kms",
    "lakeformation",
    "lambda",
    "lex-models",
    "lex-runtime",
    "lexv2-models",
    "lexv2-runtime",
    "license-manager",
    "lightsail",
    "location",
    "logs",
    "lookoutequipment",
    "lookoutmetrics",
    "lookoutvision",
    "machinelearning",
    "macie",
    "macie2",
    "managedblockchain",
    "marketplace-catalog",
    "marketplace-entitlement",
    "marketplacecommerceanalytics",
    "mediaconnect",
    "mediaconvert",
    "medialive",
    "mediapackage",
    "mediapackage-vod",
    "mediastore",
    "mediastore-data",
    "mediatailor",
    "memorydb",
    "meteringmarketplace",
    "mgh",
    "mgn",
    "migration-hub-refactor-spaces",
    "migrationhub-config",
    "migrationhubstrategy",
    "mobile",
    "mq",
    "mturk",
    "mwaa",
    "neptune",
    "network-firewall",
    "networkmanager",
    "nimble",
    "opensearch",
    "opsworks",
    "opsworkscm",
    "organizations",
    "outposts",
    "panorama",
    "personalize",
    "personalize-events",
    "personalize-runtime",
    "pi",
    "pinpoint",
    "pinpoint-email",
    "pinpoint-sms-voice",
    "polly",
    "pricing",
    "proton",
    "qldb",
    "qldb-session",
    "quicksight",
    "ram",
    "rbin",
    "rds",
    "rds-data",
    "redshift",
    "redshift-data",
    "rekognition",
    "resiliencehub",
    "resource-groups",
    "resourcegroupstaggingapi",
    "robomaker",
    "route53",
    "route53-recovery-cluster",
    "route53-recovery-control-config",
    "route53-recovery-readiness",
    "route53domains",
    "route53resolver",
    "rum",
    "s3",
    "s3control",
    "s3outposts",
    "sagemaker",
    "sagemaker-a2i-runtime",
    "sagemaker-edge",
    "sagemaker-featurestore-runtime",
    "sagemaker-runtime",
    "savingsplans",
    "schemas",
    "sdb",
    "secretsmanager",
    "securityhub",
    "serverlessrepo",
    "service-quotas",
    "servicecatalog",
    "servicecatalog-appregistry",
    "servicediscovery",
    "ses",
    "sesv2",
    "shield",
    "signer",
    "sms",
    "sms-voice",
    "snow-device-management",
    "snowball",
    "sns",
    "sqs",
    "ssm",
    "ssm-contacts",
    "ssm-incidents",
    "sso",
    "sso-admin",
    "sso-oidc",
    "stepfunctions",
    "storagegateway",
    "sts",
    "support",
    "swf",
    "synthetics",
    "textract",
    "timestream-query",
    "timestream-write",
    "transcribe",
    "transfer",
    "translate",
    "voice-id",
    "waf",
    "waf-regional",
    "wafv2",
    "wellarchitected",
    "wisdom",
    "workdocs",
    "worklink",
    "workmail",
    "workmailmessageflow",
    "workspaces",
    "workspaces-web",
    "xray",
]
ResourceServiceName = Literal[
    "cloudformation",
    "cloudwatch",
    "dynamodb",
    "ec2",
    "glacier",
    "iam",
    "opsworks",
    "s3",
    "sns",
    "sqs",
]
PaginatorName = Literal["list_experiments", "list_features", "list_launches", "list_projects"]

==> mypy-boto3-evidently-1.24.72.tar.gz: mypy-boto3-evidently-1.24.72/mypy_boto3_evidently/literals.py <==
"""
Type annotations for evidently service literal definitions.

[Open documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_evidently/literals/)

Usage::

    ```python
    from mypy_boto3_evidently.literals import ChangeDirectionEnumType

    data: ChangeDirectionEnumType = "DECREASE"
    ```
"""
import sys

if sys.version_info >= (3, 9):
    from typing import Literal
else:
    from typing_extensions import Literal


__all__ = (
    "ChangeDirectionEnumType",
    "EventTypeType",
    "ExperimentBaseStatType",
    "ExperimentReportNameType",
    "ExperimentResultRequestTypeType",
    "ExperimentResultResponseTypeType",
    "ExperimentStatusType",
    "ExperimentStopDesiredStateType",
    "ExperimentTypeType",
    "FeatureEvaluationStrategyType",
    "FeatureStatusType",
    "LaunchStatusType",
    "LaunchStopDesiredStateType",
    "LaunchTypeType",
    "ListExperimentsPaginatorName",
    "ListFeaturesPaginatorName",
    "ListLaunchesPaginatorName",
    "ListProjectsPaginatorName",
    "ListSegmentReferencesPaginatorName",
    "ListSegmentsPaginatorName",
    "ProjectStatusType",
    "SegmentReferenceResourceTypeType",
    "VariationValueTypeType",
    "CloudWatchEvidentlyServiceName",
    "ServiceName",
    "ResourceServiceName",
    "PaginatorName",
    "RegionName",
)


ChangeDirectionEnumType = Literal["DECREASE", "INCREASE"]
EventTypeType = Literal["aws.evidently.custom", "aws.evidently.evaluation"]
ExperimentBaseStatType = Literal["Mean"]
ExperimentReportNameType = Literal["BayesianInference"]
ExperimentResultRequestTypeType = Literal[
    "BaseStat", "ConfidenceInterval", "PValue", "TreatmentEffect"
]
ExperimentResultResponseTypeType = Literal[
    "ConfidenceIntervalLowerBound",
    "ConfidenceIntervalUpperBound",
    "Mean",
    "PValue",
    "TreatmentEffect",
]
ExperimentStatusType = Literal["CANCELLED", "COMPLETED", "CREATED", "RUNNING", "UPDATING"]
ExperimentStopDesiredStateType = Literal["CANCELLED", "COMPLETED"]
ExperimentTypeType = Literal["aws.evidently.onlineab"]
FeatureEvaluationStrategyType = Literal["ALL_RULES", "DEFAULT_VARIATION"]
FeatureStatusType = Literal["AVAILABLE", "UPDATING"]
LaunchStatusType = Literal["CANCELLED", "COMPLETED", "CREATED", "RUNNING", "UPDATING"]
LaunchStopDesiredStateType = Literal["CANCELLED", "COMPLETED"]
LaunchTypeType = Literal["aws.evidently.splits"]
ListExperimentsPaginatorName = Literal["list_experiments"]
ListFeaturesPaginatorName = Literal["list_features"]
ListLaunchesPaginatorName = Literal["list_launches"]
ListProjectsPaginatorName = Literal["list_projects"]
ListSegmentReferencesPaginatorName = Literal["list_segment_references"]
ListSegmentsPaginatorName = Literal["list_segments"]
ProjectStatusType = Literal["AVAILABLE", "UPDATING"]
SegmentReferenceResourceTypeType = Literal["EXPERIMENT", "LAUNCH"]
VariationValueTypeType = Literal["BOOLEAN", "DOUBLE", "LONG", "STRING"]
CloudWatchEvidentlyServiceName = Literal["evidently"]
ServiceName = Literal[
    "accessanalyzer",
    "account",
    "acm",
    "acm-pca",
    "alexaforbusiness",
    "amp",
    "amplify",
    "amplifybackend",
    "amplifyuibuilder",
    "apigateway",
    "apigatewaymanagementapi",
    "apigatewayv2",
    "appconfig",
    "appconfigdata",
    "appflow",
    "appintegrations",
    "application-autoscaling",
    "application-insights",
    "applicationcostprofiler",
    "appmesh",
    "apprunner",
    "appstream",
    "appsync",
    "athena",
    "auditmanager",
    "autoscaling",
    "autoscaling-plans",
    "backup",
    "backup-gateway",
    "backupstorage",
    "batch",
    "billingconductor",
    "braket",
    "budgets",
    "ce",
    "chime",
    "chime-sdk-identity",
    "chime-sdk-media-pipelines",
    "chime-sdk-meetings",
    "chime-sdk-messaging",
    "cloud9",
    "cloudcontrol",
    "clouddirectory",
    "cloudformation",
    "cloudfront",
    "cloudhsm",
    "cloudhsmv2",
    "cloudsearch",
    "cloudsearchdomain",
    "cloudtrail",
    "cloudwatch",
    "codeartifact",
    "codebuild",
    "codecommit",
    "codedeploy",
    "codeguru-reviewer",
    "codeguruprofiler",
    "codepipeline",
    "codestar",
    "codestar-connections",
    "codestar-notifications",
    "cognito-identity",
    "cognito-idp",
    "cognito-sync",
    "comprehend",
    "comprehendmedical",
    "compute-optimizer",
    "config",
    "connect",
    "connect-contact-lens",
    "connectcampaigns",
    "connectparticipant",
    "controltower",
    "cur",
    "customer-profiles",
    "databrew",
    "dataexchange",
    "datapipeline",
    "datasync",
    "dax",
    "detective",
    "devicefarm",
    "devops-guru",
    "directconnect",
    "discovery",
    "dlm",
    "dms",
    "docdb",
    "drs",
    "ds",
    "dynamodb",
    "dynamodbstreams",
    "ebs",
    "ec2",
    "ec2-instance-connect",
    "ecr",
    "ecr-public",
    "ecs",
    "efs",
    "eks",
    "elastic-inference",
    "elasticache",
    "elasticbeanstalk",
    "elastictranscoder",
    "elb",
    "elbv2",
    "emr",
    "emr-containers",
    "emr-serverless",
    "es",
    "events",
    "evidently",
    "finspace",
    "finspace-data",
    "firehose",
    "fis",
    "fms",
    "forecast",
    "forecastquery",
    "frauddetector",
    "fsx",
    "gamelift",
    "gamesparks",
    "glacier",
    "globalaccelerator",
    "glue",
    "grafana",
    "greengrass",
    "greengrassv2",
    "groundstation",
    "guardduty",
    "health",
    "healthlake",
    "honeycode",
    "iam",
    "identitystore",
    "imagebuilder",
    "importexport",
    "inspector",
    "inspector2",
    "iot",
    "iot-data",
    "iot-jobs-data",
    "iot1click-devices",
    "iot1click-projects",
    "iotanalytics",
    "iotdeviceadvisor",
    "iotevents",
    "iotevents-data",
    "iotfleethub",
    "iotsecuretunneling",
    "iotsitewise",
    "iotthingsgraph",
    "iottwinmaker",
    "iotwireless",
    "ivs",
    "ivschat",
    "kafka",
    "kafkaconnect",
    "kendra",
    "keyspaces",
    "kinesis",
    "kinesis-video-archived-media",
    "kinesis-video-media",
    "kinesis-video-signaling",
    "kinesisanalytics",
    "kinesisanalyticsv2",
    "kinesisvideo",
    "kms",
    "lakeformation",
    "lambda",
    "lex-models",
    "lex-runtime",
    "lexv2-models",
    "lexv2-runtime",
    "license-manager",
    "license-manager-user-subscriptions",
    "lightsail",
    "location",
    "logs",
    "lookoutequipment",
    "lookoutmetrics",
    "lookoutvision",
    "m2",
    "machinelearning",
    "macie",
    "macie2",
    "managedblockchain",
    "marketplace-catalog",
    "marketplace-entitlement",
    "marketplacecommerceanalytics",
    "mediaconnect",
    "mediaconvert",
    "medialive",
    "mediapackage",
    "mediapackage-vod",
    "mediastore",
    "mediastore-data",
    "mediatailor",
    "memorydb",
    "meteringmarketplace",
    "mgh",
    "mgn",
    "migration-hub-refactor-spaces",
    "migrationhub-config",
    "migrationhubstrategy",
    "mobile",
    "mq",
    "mturk",
    "mwaa",
    "neptune",
    "network-firewall",
    "networkmanager",
    "nimble",
    "opensearch",
    "opsworks",
    "opsworkscm",
    "organizations",
    "outposts",
    "panorama",
    "personalize",
    "personalize-events",
    "personalize-runtime",
    "pi",
    "pinpoint",
    "pinpoint-email",
    "pinpoint-sms-voice",
    "pinpoint-sms-voice-v2",
    "polly",
    "pricing",
    "privatenetworks",
    "proton",
    "qldb",
    "qldb-session",
    "quicksight",
    "ram",
    "rbin",
    "rds",
    "rds-data",
    "redshift",
    "redshift-data",
    "redshift-serverless",
    "rekognition",
    "resiliencehub",
    "resource-groups",
    "resourcegroupstaggingapi",
    "robomaker",
    "rolesanywhere",
    "route53",
    "route53-recovery-cluster",
    "route53-recovery-control-config",
    "route53-recovery-readiness",
    "route53domains",
    "route53resolver",
    "rum",
    "s3",
    "s3control",
    "s3outposts",
    "sagemaker",
    "sagemaker-a2i-runtime",
    "sagemaker-edge",
    "sagemaker-featurestore-runtime",
    "sagemaker-runtime",
    "savingsplans",
    "schemas",
    "sdb",
    "secretsmanager",
    "securityhub",
    "serverlessrepo",
    "service-quotas",
    "servicecatalog",
    "servicecatalog-appregistry",
    "servicediscovery",
    "ses",
    "sesv2",
    "shield",
    "signer",
    "sms",
    "sms-voice",
    "snow-device-management",
    "snowball",
    "sns",
    "sqs",
    "ssm",
    "ssm-contacts",
    "ssm-incidents",
    "sso",
    "sso-admin",
    "sso-oidc",
    "stepfunctions",
    "storagegateway",
    "sts",
    "support",
    "support-app",
    "swf",
    "synthetics",
    "textract",
    "timestream-query",
    "timestream-write",
    "transcribe",
    "transfer",
    "translate",
    "voice-id",
    "waf",
    "waf-regional",
    "wafv2",
    "wellarchitected",
    "wisdom",
    "workdocs",
    "worklink",
    "workmail",
    "workmailmessageflow",
    "workspaces",
    "workspaces-web",
    "xray",
]
ResourceServiceName = Literal[
    "cloudformation",
    "cloudwatch",
    "dynamodb",
    "ec2",
    "glacier",
    "iam",
    "opsworks",
    "s3",
    "sns",
    "sqs",
]
PaginatorName = Literal[
    "list_experiments",
    "list_features",
    "list_launches",
    "list_projects",
    "list_segment_references",
    "list_segments",
]
RegionName = Literal[
    "ap-northeast-1",
    "ap-southeast-1",
    "ap-southeast-2",
    "eu-central-1",
    "eu-north-1",
    "eu-west-1",
    "us-east-1",
    "us-east-2",
    "us-west-2",
]
